#
# spec file for package python-executing
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-executing
Version:        2.0.1
Release:        1.5
Summary:        Get the currently executing AST node of a frame, and other information
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/alexmojaki/executing
Source:         https://files.pythonhosted.org/packages/source/e/executing/executing-%{version}.tar.gz
BuildRequires:  %{python_module asttokens}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module littleutils}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools_scm >= 4.0.0}
BuildRequires:  %{python_module toml}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Get the currently executing AST node of a frame, and other information

%prep
%setup -q -n executing-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest discover -v

%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitelib}/executing
%{python_sitelib}/executing-%{version}*-info

%changelog
* Tue Nov  7 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.1:
  * fix: self.fail() is only available in TestCase classes
  * fix: mark expressions which can be evaluated at compile time
    as deadcode
  * fix: implemented DELETE_DEREF
  * feat: 3.12 support for the PositionNodeFinder
  * feat: support LOAD_CONST
  * test: verify exception generation for asserts >= python 3.11.2
  * test: skip test of module_files for the SentinelNodeFinder
  * test: do not check qualnames for files with syntax errors
  * fix: handle List/Set/DictComp inlining
  * fix: handle super optimization
  * fix: type parameter related things
  * fix: f-string
  * fix: disabled type checking for 3.12
  * test: added test results for 3.12
  * fix: workaround for a bug in six
  * remove python2 code
  * feat: support for __iter__
  * feat: support for __next__
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Dec  2 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.2.0
  Merge pull request #56 from alexmojaki/init_tokens
    Use new asttokens.ASTText
- Update to 1.1.1
  tox is breaking weirdly with too much parallelism
- Update to 1.1.0
  3.11 in setup.cfg
- Update to 1.0.0
  Merge pull request #46 from alexmojaki/checkcache
    Always check linecache
- Update to 0.10.0
  Merge pull request #45 from alexmojaki/reload
    Clear caches when modules are reloaded
- Update to 0.9.1
  Merge pull request #41 from alexmojaki/node_linenos
    Extract node_linenos to account for end_lineno and use in assert_linenos
- Update to 0.9.0
  * Merge pull request #38 from alexmojaki/pwwang/master
    Support STORE_ATTR and STORE_SUBSCR
* Sun Mar 27 2022 Dirk Müller <dmueller@suse.com>
- update to 0.8.3:
  * handle new iphython cell code names
  * link to futurecoder
* Thu Dec  2 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Skip python 3.6 since python-asttokens dropped it
* Tue Nov  2 2021 pgajdos@suse.com
- version update to 0.8.2
  * no upstream changelog
- %%check: use %%pyunittest rpm macro
* Wed Dec  2 2020 ecsos <ecsos@opensuse.org>
- Update to 0.5.3
  - Handle pypy saying the current instruction is an extended arg
- Changes from 0.5.2
  - Convert path to string before checking filename cache
- Changes from 0.5.1
  - Get top level statement containing IPython node
- Changes from 0.5.0
  - Also cache Source objects by contents (lines)
- Changes from 0.4.4
  - Move packaging metadata into setup.cfg
- Changes from 0.4.3
  - Bump to 0.4.3
* Wed Mar 11 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.4.2
